import string

"""
details.py

Build and installation details for this PyKDE component.

Copyright (C) 2003-2006 David Boddie <david@boddie.org.uk>

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
"""

def find_details():

    details = \
    {
        # Project name - the filename of the Python module should
        # be derived from this: e.g. DefaultPython -> defaultpython.py
        "name":             "PythonLauncherApplet",
        
        # A pretty name for this module and its description
        "pretty name":      "Python Launcher Applet",
        "comment":          "Provides support for launching Python panel applets.",
        
        # Change this function or class name in your Python module to match
        # the name of the factory class.
        "factory":          "init_applet",
        
        # Destination filename in each destination for the icons described
        # below.
        "icon":             "pythonlauncherapplet.png",
        
        # Specific Panel Applet attributes
        "unique":           "false",
        "C++ factory":      ("", "init"),
    }
    
    requires = \
    {
        "library":     "panel_launcher.cpp",
        
        # Specify other libraries beneath the Python library directory.
        # A None value for the path causes the module to be searched for
        # within the Python library directories.
        "python":       [],
        
        # Specify other items to include alongside the module in its own
        # directory.
        "other items":  ["pythonlauncherapplet.py", "image.png"]
    }
    
    provides = \
    {
        ".py":
        {
            "filename":     "launcher",
            "directory":    string.lower(details["name"]),
            "destination":  "%(kde dir)s/share/apps/"
        },
        
        ".so":
        {
            "name":         string.lower(details["name"]),
            "filename":     "lib" + string.lower(details["name"]),
            "destination":  "%(kde dir)s/lib/kde3"
        },
        
        ".la":
        {
            "contents":     linking_template,
            "filename":     "lib" + string.lower(details["name"]),
            "destination":  "%(kde dir)s/lib/kde3"
        },
        
        ".desktop":
        {
            # Give the path beneath which the desktop file should be stored.
            "filename":     string.lower(details["name"]),
            "destination":  "%(kde dir)s/share/apps/kicker/applets",
            "contents":     desktop_template
        },
        
        "icons":
        {
            "destination":  "%(kde dir)s/share/icons/",
            
            # The section under which the icon will be stored for each theme
            # and size.
            "icon type":    "apps",
            
            "themes":
            {
              #   Theme          Size    Source icon
                "hicolor":
                {
                  "22x22": [("image.png", "pythonlauncherapplet.png")],
                  "16x16": [("image.png", "pythonlauncherapplet.png")]
                },
                "crystalsvg":
                {
                  "22x22": [("image.png", "pythonlauncherapplet.png")],
                  "16x16": [("image.png", "pythonlauncherapplet.png")]
                }
            }
        }
    }
    
    return details, requires, provides


# Do not change anything below this line. -------------------------------------

linking_template = \
"""
# %(lib)s.la - a libtool library file
# Generated by build.py
#
# Please DO NOT delete this file!
# It is necessary for linking the library.

# The name that we can dlopen(3).
dlname='%(lib)s.so'

# Names of this library.
library_names='%(lib)s.so %(lib)s.so %(lib)s.so'

# The name of the static archive.
old_library=''

# Libraries that this one depends upon.
dependency_libs='%(deps)s'

# Version information for %(lib)s.
current=0
age=0
revision=0

# Is this an already installed library?
installed=yes

# Files to dlopen/dlpreopen
dlopen=''
dlpreopen=''

# Directory that this library needs to be installed in:
libdir='%(libdest)s'
"""

desktop_template = \
"""[Desktop Entry]
Name=%(pretty name)s
Comment=%(comment)s
Icon=%(icon)s
X-KDE-Library=%(lib)s
X-KDE-UniqueApplet=%(unique)s
"""
