#!/usr/bin/env python

"""
launcher.py

General launcher for Python panel applets.

Copyright (C) 2003-2006 David Boddie <david@boddie.org.uk>

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
"""

import glob, imp, os, string, sys
import qt, sip


def find_applet(configFile):

    # The text following the initial "lib" up to the first underscore is
    # probably the name we want.
    
    if configFile[:3] != "lib":
    
        return None
    
    at = string.find(configFile, "_", 3)
    
    if at == -1:
    
        # This may be a unique applet; take the name from the initial
        # "lib" up to the final "rc".
        applet_name = configFile[3:-2]
    
    else:
    
        applet_name = configFile[3:at]
    
    # Look in some appropriate places for a directory of this name.
    this_dir = os.path.split(__file__)[0]
    parent_dir = os.path.split(this_dir)[0]
    applet_dir = os.path.join(parent_dir, applet_name)
    
    if not os.path.isdir(applet_dir):
    
        return None
    
    # Construct a filename for this module.
    applet_module = applet_name + os.extsep + "py"
    
    path = os.path.join(applet_dir, applet_module)
    
    try:
    
        fh, filename, stuff = imp.find_module(applet_name, [applet_dir])
        
        # Insert the module path at the beginning of the system search
        # path to help the applet module find any support modules it has
        # in its own directory.
        sys.path.insert(0, path)
        
        # Load the module.
        module = imp.load_module(applet_name, fh, filename, stuff)
    
    except ImportError:
    
        raise
    
    return module


def init_applet(parent, configFile, name):

    # Use the configFile value to determine the name and location of the
    # relevant applet.
    
    parent = sip.wrapinstance(parent, qt.QWidget)
    
    # Find the applet module.
    module = find_applet(configFile)
    
    if module is not None:
    
        # Call the init function in the module.
        applet = module.init(parent, configFile, name)
        
        if applet:
            return sip.unwrapinstance(applet)
    
    # Return the applet instance created.
    return None
