#!/usr/bin/env python

"""
pythonlauncherapplet.py

An applet to show the status of the Python panel applet launcher library.

Copyright (C) 2003-2006 David Boddie <david@boddie.org.uk>

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
"""

import qt, sip

from kdecore import i18n, KAboutData, KGlobal
from kdeui import KAboutApplication, KPanelApplet

import os, sys



def init(parent, configFile, name):

    KGlobal.locale().insertCatalogue(name)
    
    applet = AppletClass(
        configFile, KPanelApplet.Normal, KPanelApplet.About, parent,
        "pythonlauncherapplet"
        )
    
    return applet


# Define a class based on the KPanelApplet class.

class AppletClass(KPanelApplet):

    def __init__(self, config_file, panel_type, panel_actions, parent, name):
    
        KPanelApplet.__init__(
            self, config_file, panel_type, panel_actions, parent, name
            )
        
        self.name = name
        self.parent = parent
        self.config_file = config_file
        
        self._about_data = None
        
        self.version = "0.10 (31st August 2006)"
        self.program_name = str(i18n("Python Panel Applet Launcher"))
        self.program_description = str(i18n("Python panel applet launcher"))
        
        self.thanks = str(i18n(
            "Thanks to Jim Bublitz and Phil Thompson for providing advice " + \
            "on using PyKDE and SIP."
            ))
        
        self.authors = \
        [
            ( "David Boddie", str(i18n("Applet author")),
              "david@boddie.org.uk", "http://www.boddie.org.uk/" )
        ]
        
        # Record the path to this module. We could obtain this from the general
        # launcher, since it has to locate this module anyway.
        
        self.module_path = __file__
        
        # Find a pixmap in the directory where this module resides.
        appdir, appmodule = os.path.split(self.module_path)
        
        pixmap_file = os.path.join(appdir, "image" + os.extsep + "png")
        
        if os.path.exists(pixmap_file):
        
            pixmap = qt.QPixmap(pixmap_file)
            self.image = pixmap.convertToImage()
        
        else:
        
            self.setBackgroundMode(self.NoBackground)
            self.brush = qt.QBrush(self.darkRed)
    
    def widthForHeight(self, height):
    
        return height
    
    def heightForWidth(self, width):
    
        return width
    
    def about(self):
    
        if self._about_data is None:
        
            # The QStrings returned from the i18n function need to be
            # converted to strings for the following constructor.
            # The program name and program description strings must also be
            # translated and defined elsewhere rather than being translated
            # and converted to strings inline.
            
            self._about_data = KAboutData(
                self.name, self.program_name, self.version,
                self.program_description,
                KAboutData.License_GPL, "(c) 2003-2006, David Boddie",
                self.thanks
                )
            
            # You _must_ set the license text if the License_Custom
            # value is used in the constructor.
            #self._about_data.setLicenseText(self.license)
            
            # It looks like all arguments are required for the addAuthor
            # method of the KAboutData class.
            
            for author, role, email, website in self.authors:
            
                self._about_data.addAuthor(
                    author, role, email, website
                    )
        
        self._about_dialog = KAboutApplication(self._about_data)
        self._about_dialog.show()
    
    def mousePressEvent(self, event):
    
        if event.button() == qt.QMouseEvent.LeftButton:
        
            self.infoWindow = qt.QTextBrowser()
            self.infoWindow.setText("\n".join(
                map(lambda (name, module): "%s:%s" % (name, repr(module)),
                    sys.modules.items())))
            self.infoWindow.show()
    
    def paintEvent(self, event):
    
        """paintEvent(self, event)
        
        Redraw the contents of the applet's widget using the information
        provided in the QPaintEvent object supplied.
        """
        
        # Don't bother to redraw if the widget is not visible.
        if not self.isVisible(): return
        
        painter = qt.QPainter(self)
        area = self.rect()
        
        # Paranoia: if the image was installed then render it, otherwise
        # fill in the applet's panel space in a solid colour.
        
        if hasattr(self, "image"):
            painter.drawImage(area, self.image)
        else:
            painter.fillRect(area, self.brush)
